@@ -215,7 +215,7 @@ sub _ViewFile {
         TemplateFile => 'AdminSystemFiles/File',
         Data         => {
             File    => $FileDetails{Name},
-            Content => ${$Content},
+            Content => $Content ? ${$Content} : '',
         },
     );
 
@@ -617,24 +617,29 @@ sub FileDetails {
     my $File = $Param{File};
 
     my $Stat        = stat($File);
-    my $Changed     = $Stat->mtime();
-    my $Created     = $Stat->ctime();
-    my $Mode        = $Stat->mode();
-    my $Permissions = sprintf '%04o', $Mode & 07777;    ## no critic
-    my $User        = getgrgid( stat($File)->gid );     ## no critic
-    my $Group       = getpwuid( stat($File)->uid );     ## no critic
+    my $Changed     = $Stat ? $Stat->mtime() : '';
+    my $Created     = $Stat ? $Stat->ctime() : '';
+    my $Mode        = $Stat ? $Stat->mode() : '';
+    my $Permissions = $Stat ? ( sprintf '%04o', $Mode & 07777 ) : '';    ## no critic
+    my $User        = $Stat ? getgrgid( $Stat->gid ) : '';               ## no critic
+    my $Group       = $Stat ? getpwuid( $Stat->uid ) : '';               ## no critic
     my $FullPath    = $File;
     my $FileName    = $File;
 
     $FileName =~ s{.+\/(.*)}{$1}smxg;
     $File     =~ s{$Home\/}{}smxg;
 
-    my $ChangedTimeStamp = $TimeObject->SystemTime2TimeStamp(
+    my $ChangedTimeStamp = $Stat
+        ? $TimeObject->SystemTime2TimeStamp(
         SystemTime => $Changed,
-    );
-    my $CreatedTimeStamp = $TimeObject->SystemTime2TimeStamp(
+        )
+        : '';
+
+    my $CreatedTimeStamp = $Stat
+        ? $TimeObject->SystemTime2TimeStamp(
         SystemTime => $Created,
-    );
+        )
+        : '';
 
     my %FileDetails = (
         Type         => $Param{Type},
@@ -647,11 +652,11 @@ sub FileDetails {
         Group        => $Group,
         Permissions  => $Permissions,
         Package      => $Self->{Files}->{$FullPath}->{Package} || '',
-        State        => $Self->{Files}->{$FullPath}->{State} || 'Warning',
+        State        => $Stat ? ( $Self->{Files}->{$FullPath}->{State} || 'Warning' ) : 'Missing or not readable',
         StateMessage => $Self->{Files}->{$FullPath}->{StateMessage} || 'Unknown',
     );
 
-    return %FileDetails if !$Param{Extended};
+    return %FileDetails if !$Param{Extended} || !$Stat;
 
     my %Extended = $Self->FileDetailsExtended(
         %Param,
